@@ -1,4 +1,7 @@
-select /*+ use_nl(c,a) */ a.sid,a.username,b.name,c.value
+select /*+ use_nl(c,a) */ a.sid "Sid",
+a.username "Username",
+b.name "Name",
+c.value "Value"
 from v$session a,v$statname b,v$sesstat c
 where a.sid = c.sid and b.statistic# = c.statistic#
 and a.sid = ?
